<?php

namespace Drupal\site_verify\Routing;

use Drupal\Core\Database\Connection;
use Drupal\Core\DependencyInjection\AutowireTrait;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Defines dynamic routes.
 */
class SiteVerifyRoutes implements ContainerInjectionInterface {

  use AutowireTrait;

  /**
   * Constructs a new SiteVerifyRoutes object.
   */
  public function __construct(
    protected Connection $database,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function routes() {
    $verifications = $this->database->select('site_verify', 'site_verify')
      ->fields('site_verify', ['svid', 'file'])
      ->condition('file', '', '<>')
      ->execute()
      ->fetchAll();
    $route_collection = new RouteCollection();
    foreach ($verifications as $verification) {
      $route = new Route(
        $verification->file, [
          '_controller' => '\Drupal\site_verify\Controller\SiteVerifyController::verificationsFileContent',
          'svid' => $verification->svid,
        ],
        ['_access' => 'TRUE']
      );
      // Is this a security issue?
      // https://zgadzaj.com/development/php/drupal/8/how-to-generate-a-machine-name-in-drupal-8
      $route_collection->add('site_verify.' . $verification->file, $route);
    }
    return $route_collection;
  }

}
